@@ -381,9 +381,9 @@ export class Encounter extends Model {
     `;
   }
 
-  static async buildSyncLookupQueryDetails() {
+  static buildSyncLookupQueryDetails() {
     return {
-      select: await buildEncounterLinkedLookupSelect(this, {
+      select: buildEncounterLinkedLookupSelect(this, {
         isLabRequestValue: 'new_labs.encounter_id IS NOT NULL',
       }),
       joins: `
